`switchdb` module
*****************

Fabric tasks
------------

.. autofunction:: django_fabfile.switchdb.recover_backup
.. autofunction:: django_fabfile.switchdb.recover_master
.. autofunction:: django_fabfile.switchdb.return_backup
.. autofunction:: django_fabfile.switchdb.return_master
.. autofunction:: django_fabfile.switchdb.switch_to_backup
.. autofunction:: django_fabfile.switchdb.switch_to_master

Internals
---------

.. automodule:: django_fabfile.switchdb
   :members:

.. autofunction:: django_fabfile.switchdb.failover
.. autofunction:: django_fabfile.switchdb.recover
